# History

-----

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/), and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## Unreleased

## 0.5.0 - 2023-05-12

***Added:***

- Build standalone distributions

## 0.4.0 - 2022-02-13

***Added:***

- Bump the version of `hatch-mypyc`

## 0.3.0 - 2022-01-19

***Added:***

- Use `hatch-vcs`
- Bump the version of `hatch-mypyc`

## 0.2.0 - 2022-01-12

***Added:***

- Bump the version of `hatch-mypyc`

## 0.1 - 2022-01-04

This is the initial public release.
